# ======================================================================
#                                 DoIt4Me 
#             Automate Administrative Tasks on Windows NT Networks
#
#
#  See help.txt for explainations of each function.
#  
#
# Copyright (C) 2001  Alessandro Augusto
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
# GNU Web Site: www.gnu.org
#
# Contacting the author:
# <Questions, commentaries or references to the author> 
#
#  Alessandro Augusto
#  alaugusto@yahoo.com.br
#
# ======================================================================

use strict;
use Win32; # para funcao shutdown 
use Win32::Service;
use Win32::TieRegistry(Delimiter=>"/"); 
use Net::Ping;


# Check what argument was choosed on the command line
# Ex. 1 for auditing, 2 for configuring...

my $opcao = shift; 

my $server;
my $remote; 
my ($caminho, $chave, $valor);
my($pc, $ultimo_indice, $i, $j); 
my ($rebootmessage, $timetoreboot, $reboot_or_shutdown);
my @computerlist;
my @computer_off_list;
my ($p, $computer, $is_alive);

# There is one Procedure for each command line option
# Option 1 = Auditing

if ($opcao eq 1)     
 {
  &getRegValues;
 }

 # Option 2 = Configure the Registry

 elsif ($opcao eq 2)
  {
   &changeRegValues;
  }
 
 # Option 3 = Check status of ALL NT services

 elsif ($opcao eq 3)
  {
   &get_services_status;
  } 

 # Option 4 = Check a subset of NT services

 elsif ($opcao eq 4)
  {
    &get_some_services_status; 
  }


 # Option 5 = Start or Stop a subset of NT services

 elsif ($opcao eq 5)
  {
   &change_services_status;
  } 
 
 # Option 6 = Ping a subset of computers

 elsif ($opcao eq 6)
  {
    &ping; 
  }

 # Option 7 = Reboot a subset of computers

 elsif ($opcao eq 7)
  {
    &reboot; 
  }

 # Opcao 8 = Display Help

 elsif ($opcao eq 8)
  {
    `notepad help.txt`; 
  }

 # Else all the options above, just display the usage form

 else
  {
   &usage;
  }

  
# ======================================================================
#                        Procedure GetRegValues    
#
# This procedure check the values of a subset of Registry keys of a subset
# of computers. The subset of Registry values are specified on the file
# <doit4me_folder>/cfg/regaudit.cfg and the subset of computers are 
# specified on the file <doit4me_folder>/cfg/pclist.cfg 
#
# Syntax of the file <doit4me_folder>/cfg/regaudit.cfg: key;Path 
# (one key;Path for each line)
#
# ======================================================================

sub getRegValues { 
    my($value,$data); 
    my %regkeys = (); 
    
    my $datafile = "./cfg/regaudit.cfg"; 
    if (-e $datafile) { 
        open(FL,$datafile) || die "There is a problem to open the file $datafile: $!\n"; 
        while(<FL>) { 
            chomp; 

	    # Ignore comentaries and blank lines on the configuration files 
            next if ($_ =~ m/^#/); 
            next if ($_ =~ m/^\s+$/); 
            my($key,$path) = split(/;/,$_); 
            $regkeys{$key} = $path; 
        } 
        close(FL); 

           # The subset of computers are specified on the <doit4me_folder>/cfg/pclist.cfg file
           my $pclistfile = "./cfg/pclist.cfg"; 

           if (-e $pclistfile) 
            { 
              open(FL,$pclistfile) || die "There is a problem to open the file $pclistfile: $!\n"; 
              while(<FL>) 
               { 
                 chomp; 

                 # Ignore comentaries and blank lines on the configuration files
                 next if ($_ =~ m/^#/); 
                 next if ($_ =~ m/^\s+$/); 
                 my($pc) = split(/;/,$_); 

                 # First check if the computer is alive on the network

                 $computer= $pc;
                 &pc_exist($computer);
                 if ($is_alive eq 1) { push(@computerlist, $pc); }
                   else { push(@computer_off_list, $pc); }
               } 
              close(FL); 
           } 
          
          $ultimo_indice = $#computerlist;

      print "_______________________________________________________________\n\n";
      print "                DoIt4Me Registry Auditing\n";
      print "_______________________________________________________________\n";
      print "\n\n";
      printf "%-15s %-27s %-5s\n","COMPUTER","KEY","VALUE";
      printf "%-15s %-27s %-5s\n","-" x 12, "-" x 7,"-" x 5;
      
       # if you remove the below sort command, the results wont be outputted alphabeticaly
       foreach my $key (sort keys %regkeys) 
         { 

          # in this loop, we verify the value of the current key ($key) in each computer 
          # from the computerlist file.
         
          for ($i=0; $i <= $ultimo_indice; $i++)
           {
             $server= $computerlist[$i];  # atribui o valor da posicao do vetor a variavel server
             if ($remote = $Registry->{"//$server"}) 
              { 
          
	            $value = $remote->{$regkeys{$key}}; 
        	    $data = $value->{$key}; 
        	    if (defined $data) 
                     { 
                       $data = hex($data) if ($data =~ m/^0x/); 
                       printf "%-15s %-27s %-5s\n","$server","$key","$data";

             	     } 
            	    else 
		     { 
                       printf "%-15s %-27s %-5s\n","$server","$key","Not Found";

	             }
	       } 
              else 
               { 
                 print "It was not possible to connect to the $server Registry\n"; 
               } 

           } 
        print "\n\n";
        }

    } 

     # Print the Computers that are not alive on the network
     &print_not_alive;
} 

# ======================================================================
#                        Procedure ChangeRegValues
#
# This procedure changes a subset of Registry values specified on the
# the file <doit4me_folder>/cfg/regconfig.cfg on a subset of computers
#
# Syntax of the file <doit4me_folder>/cfg/regconfig.cfg: key; Path; New value
# (one key;Path;new value for each line)
#
# ======================================================================

sub changeRegValues{

    my $novos_valores_file = "./cfg/regconfig.cfg"; 
    my($value,$data,$path, $newvalue); 
    my %regkeys = (); 

    # open the file and separe the values and keys in different variables
    if (-e $novos_valores_file) 
     { 

           # open the file with the subset of computers
           my $pclistfile = "./cfg/pclist.cfg"; 
           if (-e $pclistfile) 
            { 
              open(FL,$pclistfile) || die "There is a problem to open the file $pclistfile: $!\n"; 
              while(<FL>) 
               { 
                 chomp; 

                 # Ignore comentaries and blank lines on the configuration files
                 next if ($_ =~ m/^#/); 
                 next if ($_ =~ m/^\s+$/); 
                 my($pc) = split(/;/,$_); 

                 # First check if the computer is alive on the network

                 $computer= $pc;
                 &pc_exist($computer);
                 if ($is_alive eq 1) { push(@computerlist, $pc); }
                   else { push(@computer_off_list, $pc); }

               } # end while
              close(FL); 
           } # end if 
          
          $ultimo_indice = $#computerlist;

      print "_______________________________________________________________\n\n";
      print "                DoIt4Me Registry Configure\n";
      print "_______________________________________________________________\n";
      print "\n\n";
      printf "%-15s %-27s\n","COMPUTER","STATUS";
      printf "%-15s %-27s\n","-" x 12, "-" x 7;


      for ($i=0; $i <= $ultimo_indice; $i++)
       {
        $server= $computerlist[$i];  
     
        open(FL,$novos_valores_file) || die "There is a problem to open the file $novos_valores_file: $!\n"; 
        
        while(<FL>) 
         { 
            chomp; 

	    # Ignore comentaries and blank lines on the configuration files 
            next if ($_ =~ m/^#/); 
            next if ($_ =~ m/^\s+$/); 

            my($key,$path,$newvalue) = split(/;/,$_); 

            $regkeys{$path, $key} = $newvalue;
  	    $caminho="$path";
	    $chave="$key";
	    $valor="$newvalue";
             
	    # set the new value on the Registry
	    $Registry->{"//$server/$caminho//$chave"}="$valor";

        } 
        close(FL);
        printf "%-15s %-27s\n","$server","Configured";
      } 
     } 
        
       print "\n\n"; 
       # Print the Computers that are not alive on the network
       &print_not_alive;
} 

# ======================================================================
#                        Procedure Get_services_status
#
# This procedure checks the status a ALL NT services from a subset of
# computers
#
# ======================================================================


sub get_services_status {

	my($server) = @_;
	my %svchash = ();
	my %status; 
	my(@state) = ("",
			"Stopped",
			"Start_Pending",
			"Stop_Pending",
			"Running",
			"Continue_Pending",
			"Pause_Pending",
			"Paused");

           # Subset of Computers that will be scanned and ckecked
           # file: <doit4me_folder>/cfg/pclist.cfg
           my $pclistfile = "./cfg/pclist.cfg"; 

           if (-e $pclistfile) 
            { 
              open(FL,$pclistfile) || die "There is a problem to open the file $pclistfile: $!\n"; 
              while(<FL>) 
               { 
                 chomp; 

                 # Ignore comentaries and blank lines on the configuration files 
                 next if ($_ =~ m/^#/); 
                 next if ($_ =~ m/^\s+$/); 
                 
                 my($pc) = split(/;/,$_); 

                 # First check if the computer is alive on the network

                 $computer= $pc;
                 &pc_exist($computer);
                 if ($is_alive eq 1) { push(@computerlist, $pc); }
                   else { push(@computer_off_list, $pc); }

               } 
              close(FL); 
           } 
          
          $ultimo_indice = $#computerlist;

      print "_______________________________________________________________\n\n";
      print "                DoIt4Me Services Status\n";
      print "_______________________________________________________________\n";
      print "\n\n";
      

      for ($i=0; $i <= $ultimo_indice; $i++)
       {
        $server= $computerlist[$i];  
        print "-------------------------\n";
        print "COMPUTER: $server\n";
        print "-------------------------\n";
       
       	if (Win32::Service::GetServices("\\\\$server",\%svchash)) {
		printf "%-53s %-20s\n","SERVICES","STATUS";
		printf "%-53s %-20s\n","-" x 48,"-" x 9;
		foreach my $svc (sort keys %svchash) {			
			if (Win32::Service::GetStatus("\\\\$server",$svchash{$svc},\%status)) {
				printf "%-53s %-20s\n","$svc","[$state[$status{CurrentState}]]";
			}
			else {
				&lasterror;
			}
		} 
	} 
	else {
		&lasterror;
	} 

       print "\n\n"; 
       } 

      # Print the Computers that are not alive on the network
      &print_not_alive;
}

# ======================================================================
#                        Procedure change_services_status
#
# This procedure change the status of a subset of NT services 
# Configure the file <doit4me_folder>/cfg/serviceconfig.cfg
#
# Syntax of <doit4me_folder>/cfg/serviceconfig.cfg: service; new status
# New Status = 1 starts the service
# New Status = 0 stops the service
#
# ======================================================================


sub change_services_status { 

    my %status; 
    my $status_atual;
    my(@state) = ("",
			"Stopped",
			"Start_Pending",
			"Stop_Pending",
			"Running",
			"Continue_Pending",
			"Pause_Pending",
			"Paused");

    my $srv_file = "./cfg/serviceconfig.cfg"; 
    my($srv,$srv_bit); 
    my %regkeys = (); 
    my $pclistfile = "./cfg/pclist.cfg"; 
   
        if (-e $pclistfile) 
            { 
              open(FILE,$pclistfile) || die "There is a problem to open the file $pclistfile: $!\n"; 
              while(<FILE>) 
               { 
                 chomp; 

                 # Ignore comentaries and blank lines on the configuration files 
                 next if ($_ =~ m/^#/); 
                 next if ($_ =~ m/^\s+$/); 
                 my($pc) = split(/;/,$_); 

                 # First check if the computer is alive on the network

                 $computer= $pc;
                 &pc_exist($computer);
                 if ($is_alive eq 1) { push(@computerlist, $pc); }
                   else { push(@computer_off_list, $pc); }

               } # end while
              close(FILE); 
           } 
          
          $ultimo_indice = $#computerlist;

      print "_______________________________________________________________\n\n";
      print "             DoIt4Me Change Services Status\n";
      print "_______________________________________________________________\n";
      print "\n\n";

    # open the file and separe the values and keys in different variables
    if (-e $srv_file) { 
        open(FL,$srv_file) || die "There is a problem to open the file $srv_file: $!\n"; 
        
        while(<FL>) { 
            chomp; 

	    # Ignore comentaries and blank lines on the configuration files 
            next if ($_ =~ m/^#/); 
            next if ($_ =~ m/^\s+$/); 
           
            my($srv,$srv_bit) = split(/;/,$_); 
            $regkeys{$srv} = $srv_bit; 
            
            print "SERVICE: $srv\n";
            print "-----------------------------------------\n";
            printf "%-23s %-20s\n","COMPUTER","STATUS";
            print "-----------------------------------------\n";


      for ($i=0; $i <= $ultimo_indice; $i++)
       {
        $server= $computerlist[$i];  # atribui o valor da posicao do vetor a variavel server

        # Stop the Service
        # if the New Status = 0 -> then stop the service  

        if ($srv_bit eq 0) 
         {
      
            # first of all, check the service current status to see if needs to stop or not
            # Port: verifica o status currente do servico pra ver se precisa desligar ou nao

            if (Win32::Service::GetStatus("\\\\$server",$srv,\%status)) {
                $status_atual=$state[$status{CurrentState}]; 
		
            }
            
            # The service is not stopped yet
            # Port: se o servico nao estiver desligado 

            if ($status_atual ne "Stopped") 
             {
                Win32::Service::StopService("$server","$srv");  
		printf "%-23s %-20s\n","$server","[stop]";
             }
             else
              {
		printf "%-23s %-20s\n","$server","[already stopped]";
              }  
            
         }
          
          # Ligar o Servico
          # if the New Status = 1 -> then start the service  

          elsif ($srv_bit eq 1) 
           {
          
            # first of all, check the service current status to see if needs to start or not
            # Port: verifica o status currente do servico pra ver se precisa ligar ou nao
             
            if (Win32::Service::GetStatus("\\\\$server",$srv,\%status)) {
                $status_atual=$state[$status{CurrentState}]; 
	    }
            
            # The service is not started yet
            # Port: se o servico nao estiver ligado 

            if ($status_atual ne "Running") 
             {
                Win32::Service::StartService("$server","$srv");  
		printf "%-23s %-20s\n","$server","[start]";
             }
             else
              {
		printf "%-23s %-20s\n","$server","[already started]";
              } 
           }

           # If the New Status is a value different from 0 or 1, then print an error message
           # Port: caso o valor do status seja diferente de 0 ou 1 

           else 
            {
              print "Wrong value >> $srv <<\n";
              print "Please fix the value on the serviceconfig.cfg file\n";
            }  
        } 

        print "\n\n";
        } 
   
        close(FL);

     } 

     # Print the Computers that are not alive on the network
     &print_not_alive;

} 

# ======================================================================
#                        Procedure get_some_services_status
#
# This procedure checks the status of a subset of NT services 
# Configure the subset of services on the file <doit4me_folder>/cfg/serviceaudit.cfg
# and the subset of computers on <doit4me_folder>/cfg/pclist.cfg
#
# ======================================================================

sub get_some_services_status {

	my($server) = @_;
	my %svchash = ();
	my %status; 
        my ($ultimo_indice_servicos, $servico);
        my @servicoslist;
       	my(@state) = ("",
			"Stopped",
			"Start_Pending",
			"Stop_Pending",
			"Running",
			"Continue_Pending",
			"Pause_Pending",
			"Paused");

           my $pclistfile = "./cfg/pclist.cfg"; 
           
           if (-e $pclistfile) 
            { 
              open(FL,$pclistfile) || die "There is a problem to open the file $pclistfile: $!\n"; 
              while(<FL>) 
               { 
                 chomp; 

                 # Ignore comentaries and blank lines on the configuration files 
                 next if ($_ =~ m/^#/); 
                 next if ($_ =~ m/^\s+$/); 
                 my($pc) = split(/;/,$_); 

                 # First check if the computer is alive on the network

                 $computer= $pc;
                 &pc_exist($computer);
                 if ($is_alive eq 1) { push(@computerlist, $pc); }
                   else { push(@computer_off_list, $pc); }

               }
              close(FL); 
           }
          
          $ultimo_indice = $#computerlist;

      print "_______________________________________________________________\n\n";
      print "                  DoIt4Me Services Audit\n";
      print "_______________________________________________________________\n";
      print "\n\n";
        
      my $srvlistfile = "./cfg/serviceaudit.cfg"; 
           if (-e $srvlistfile) 
            { 
              open(FIL,$srvlistfile) || die "There is a problem to open the file $srvlistfile: $!\n"; 
              while(<FIL>) 
               { 
                 chomp; 

                 # Ignore comentaries and blank lines on the configuration files 
                 next if ($_ =~ m/^#/); 
                 next if ($_ =~ m/^\s+$/); 

                 my($servico) = split(/;/,$_); 
                 push(@servicoslist, $servico);
               }
              close(FIL); 
           }
          
          $ultimo_indice_servicos = $#servicoslist;

      # Services Loop
      # Port: Laco dos Servicos

      for ($i=0; $i <= $ultimo_indice_servicos; $i++)
       {
        $servico= $servicoslist[$i];
        
        print "SERVICE: $servicoslist[$i]\n";
        print "-----------------------------------------\n";
        printf "%-23s %-20s\n","COMPUTER","STATUS";
        print "-----------------------------------------\n";

       # Computer Loop
       # Port: laco dos computadores

       for ($j=0; $j <= $ultimo_indice; $j++)
        {
           $server= $computerlist[$i];  

        # check the status of the current service

	if (Win32::Service::GetStatus("\\\\$server",$servicoslist[$i],\%status)) {
        	printf "%-23s %-20s\n","$computerlist[$j]","[$state[$status{CurrentState}]]";
	}
	else {
               printf "%-23s %-20s\n","$computerlist[$j]","[*ERROR*]";	
               
	     }

       # Port: fim do laco dos computadores
       } 

       print "\n\n";
       
       # Port: fim do for (laco dos servicos)
       } 

      # Print the Computers that are not alive on the network
      &print_not_alive;
} 

# ======================================================================
#                        Procedure ping and Pc_exist
#
# This procedure pings a subset of NT computers
# Specify the computers to be pinged on <doit4me_folder>/cfg/ping.cfg file
#
# The procedure pc_exist should be call with a host computer. The result will
# be saved on the variable "is_alive"
#
# $is_alive= 0 means the pc is down.
# $is_alive= 1 means the pc is up. 
# 
# ======================================================================

sub ping {

      print "_______________________________________________________________\n\n";
      print "                       DoIt4Me Ping\n";
      print "_______________________________________________________________\n";
      print "\n\n";

      my $pinglistfile = "./cfg/ping.cfg"; 

      if (-e $pinglistfile) 
            { 
              open(PINGFILE,$pinglistfile) || die "There is a problem to open the file $pinglistfile: $!\n"; 
              while(<PINGFILE>) 
               { 
                 chomp; 

                 # Ignore comentaries and blank lines on the configuration files 
                 next if ($_ =~ m/^#/); 
                 next if ($_ =~ m/^\s+$/); 

                 my($pc) = split(/;/,$_); 

                 $computer= $pc;
                 &pc_exist($computer);
                 if ($is_alive eq 1) { push(@computerlist, $pc); }
                   else { push(@computer_off_list, $pc); }
               }
              close(PINGFILE); 
           }

            printf "%-23s %-20s\n","COMPUTER","STATUS";
            print "-----------------------------------------\n";
 
          $ultimo_indice = $#computerlist;
          @computerlist= sort(@computerlist);
          for ($i=0; $i <= $ultimo_indice; $i++)
            {
                $server= $computerlist[$i];  
		printf "%-23s %-20s\n","$server","[Host is Alive]";
            }

          print "\n";
          $ultimo_indice = $#computer_off_list;
          @computer_off_list= sort(@computer_off_list);
          for ($i=0; $i <= $ultimo_indice; $i++)
            {
                $server= $computer_off_list[$i];  
		printf "%-23s %-20s\n","$server","[Host is Dead]";
            }


}


sub pc_exist($computer) {
    $p = Net::Ping->new("icmp");
     return $is_alive="0" unless $p->ping($computer, 2);
     return $is_alive="1";
    $p->close();
}


# ======================================================================
#                        Procedure Reboot
#
# This procedure reboots a subset of NT computers
# Specify the computers on <doit4me_folder>/cfg/reboot.cfg file
# 
# Configure the time to reboot (in seconds), the message and the set the 1 
# to reboot or 0 to shutdown on the file<doit4me_folder>/cfg/rebootmsg.cfg
#
# Syntax: x_seconds; reboot_message; reboot(1) or shutdown(0)
#
# ======================================================================


sub reboot {

      print "_______________________________________________________________\n\n";
      print "                  DoIt4Me Reboot Computers\n";
      print "_______________________________________________________________\n";
      print "\n\n";

       my $rebootlistfile = "./cfg/reboot.cfg"; 
       my $rebootmsg = "./cfg/rebootmsg.cfg";

       # Split the time and the reboot message on different variables

       if (-e $rebootmsg) 
            { 
              open(MSG,$rebootmsg) || die "There is a problem to open the file $rebootmsg: $!\n"; 
              while(<MSG>) 
               { 
                 chomp; 

                 # Ignore comentaries and blank lines on the configuration files 
                 next if ($_ =~ m/^#/); 
                 next if ($_ =~ m/^\s+$/); 

                 my($ttr,$rbtmsg,$rbt_or_stdwn) = split(/;/,$_); 
                 $timetoreboot= $ttr; 
                 $rebootmessage= $rbtmsg;
                 $reboot_or_shutdown= $rbt_or_stdwn;
                  
              }
              close(MSG); 
           }


       # Reboot the computers

       if (-e $rebootlistfile) 
            { 
              open(FIL,$rebootlistfile) || die "There is a problem to open the file $rebootlistfile: $!\n"; 
              while(<FIL>) 
               { 
                 chomp; 

                 # Ignore comentaries and blank lines on the configuration files 
                 next if ($_ =~ m/^#/); 
                 next if ($_ =~ m/^\s+$/); 

                 my($pc) = split(/;/,$_); 

                 # First check if the computer is alive on the network

                 $computer= $pc;
                 &pc_exist($computer);
                 if ($is_alive eq 1) { push(@computerlist, $pc); }
                   else { push(@computer_off_list, $pc); }

               }
              close(FIL); 
           }

        # Reboot the alive computers

        $ultimo_indice= $#computerlist;

        if ($ultimo_indice => 0) 
         {
           print "-----------------------------------------\n";
           printf "%-23s %-20s\n","COMPUTER","REBOOT STATUS";
           print "-----------------------------------------\n";
          } 

        for ($i=0; $i <= $ultimo_indice; $i++)
         {
          $pc= $computerlist[$i];
          Win32::InitiateSystemShutdown("$pc","$rebootmessage","$timetoreboot",0,"$reboot_or_shutdown");                 
          printf "%-20s %-16s\n","$pc","[Reboot in progress]";

          # syntax to Reboot
          #InitiateSystemShutdown($MachineName,$Message,$Timeout,$ForceAppsClosed,$RebootAfterShutdown);
         }          

      # Print the Computers that are not alive on the network
      print "\n\n";
      &print_not_alive;


} 

# ======================================================================
#                        Procedure LastError
#
# This procedure verify the last error occured
#
# ======================================================================


sub lasterror {
	my($str) = @_;
	my $err = Win32::FormatMessage Win32::GetLastError;
	print "ERROR: ".$str.": ".$err."\n";
}


# ======================================================================
#                        Procedure print_not_alive
#
# This procedure prints the computers that are not alive in the network
#
# ======================================================================

sub print_not_alive {

        $ultimo_indice = $#computer_off_list;
        printf "%-15s \n","COMPUTER(S) NOT ALIVE";
        printf "%-15s \n","-" x 21;
        for ($i=0; $i <= $ultimo_indice; $i++)
           {
             $server= $computer_off_list[$i];  
             printf "%-15s\n","$server";
           } 
}

# ======================================================================
#                 Procedure Display DoIt4Me arguments
#
# This procedure displays the arguments of DoIt4Me
#
# ======================================================================

sub usage {
        print "_________________________________________________________\n\n";
        print "                      DoIt4Me\n";
        print "       Automate NT Administrative Tasks Remotely\n\n";	
        print "\n";
        print " Usage: doit4me.pl <option>\n";
        print " Option: <1> Audit Registry keys\n";
        print "         <2> Configure the Registry\n";
        print "         <3> Check the status of ALL NT services\n";
        print "         <4> Check the status of a subset of NT services\n";
        print "         <5> Change NT services Status (Start/Stop)\n";
        print "         <6> Ping a subset of workstations\n";
        print "         <7> Reboot a subset of workstations\n";
        print "         <8> Help\n";
        print "\n\n";
	print " DoIt4Me, Copyright (C) 2001 Alessandro Augusto\n";
        print " DoIt4Me comes with ABSOLUTELY NO WARRANTY; for details\n";
        print " see option <8>.  This is free software, and you are welcome\n";
        print " to redistribute it under certain conditions; see DoIt4Me license.\n";
        print "_________________________________________________________\n\n";
}

